@@ -13,6 +13,7 @@
 const double R_INT_MAX = 2147483647;
 const double R_INT_MIN = -2147483648;
 
+
 SEXP c_unpack(std::vector<unsigned char> char_message);
 Rcpp::AnyVector unpackVector(const std::vector<msgpack::object> &obj_vector, bool const simplify);
 SEXP unpackVisitor(const msgpack::object &obj, bool const simplify);
@@ -353,7 +354,7 @@ SEXP unpackVisitor(const msgpack::object &obj, bool const simplify) {
 
 
 // [[Rcpp::export]]
-SEXP c_unpack(std::vector<unsigned char> char_message, bool simplify) {
+SEXP c_unpack(Rcpp::RawVector char_message, bool simplify) {
     // std::vector<unsigned char> char_message = as< std::vector<unsigned char> >(raw_message); // cast from RawVector
     // std::string message(char_message.begin(), char_message.end());
     // msgpack::object_handle oh = msgpack::unpack(message.data(), message.size());
@@ -361,7 +362,8 @@ SEXP c_unpack(std::vector<unsigned char> char_message, bool simplify) {
     
     std::size_t off = 0;
     std::size_t len = char_message.size();
-    char* mdata = reinterpret_cast<char*>(char_message.data());
+    char* mdata = reinterpret_cast<char*>(RAW(char_message));
+    // char* mdata = reinterpret_cast<char*>(char_message.data());
     // const char* dat = ss.str().data();
     std::vector<SEXP> L(0);
     while(off != len) {
